==> fastec_3.2.3_43.tar.xz: fi_update/pre/fi_update.sh <==
#!/bin/bash
set -x

SCRATCH_DIR="/home/fascam/.config/Fastec/scratch"

# Routine to compare version numbers in the form "x.y.z"
vercomp () {
    if [[ $1 == $2 ]]
    then
        return 0
    fi
    local IFS=.
    local i ver1=($1) ver2=($2)

    # fill empty fields in ver1 with zeros
    for ((i=${#ver1[@]}; i<${#ver2[@]}; i++))
    do
        ver1[i]=0
    done

    for ((i=0; i<${#ver1[@]}; i++))
    do
        if [[ -z ${ver2[i]} ]]
        then
            # fill empty fields in ver2 with zeros
            ver2[i]=0
        fi
        if ((10#${ver1[i]} > 10#${ver2[i]}))
        then
            return 1
        fi
        if ((10#${ver1[i]} < 10#${ver2[i]}))
        then
            return 2
        fi
    done
    return 0
}

# There is a conflict with the yay package and the latest version of pacman.
# We need to clear out the old yay, update pacman, then re-install yay.
update_pacman() {
    /usr/bin/logger "Update pacman/yay"
    pacman -R yay-bin --noconfirm --needed 
    pacman -Sy pacman --noconfirm --needed 

    # Make sure we have a clean folder to work in.
    [ -d /tmp/yay ] && rm -rf /tmp/yay
    mkdir /tmp/yay
    chmod a+w /tmp/yay

    cd /tmp

    # Download the yay-bin package
    wget https://aur.archlinux.org/cgit/aur.git/plain/PKGBUILD?h=yay-bin
    mv PKGBUILD\?h\=yay-bin /tmp/yay/PKGBUILD
    cd /tmp/yay

    # Build and install yay.
    sudo -u fascam makepkg -i /tmp/yay --noconfirm

    # Cleanup after ourselves.
    [ -d /tmp/yay ] && rm -rf /tmp/yay
}

# Make sure the keyring is up to date.
/usr/bin/logger "Update ArchLinux key-ring"
pacman -Sy --noconfirm archlinux-keyring

# We are only interested in the "x.y.z" format.
PVER=`pacman -Qi pacman | grep Version | cut -d':' -f2 | cut -d'-' -f1`

# Is the pacman installed on this system at a safe version?
# A result of '2' means that the pacman installed on this system
# is less than 6.0.0, which is the "safe" version.
vercomp $PVER "6.0.0"
CRESULT=$?
if [ $CRESULT -eq 2 ]; then
    update_pacman
fi

# We may need Asian fonts.
/usr/bin/logger "Make sure we have our fonts"
pacman -S --noconfirm --needed adobe-source-han-sans-cn-fonts adobe-source-han-sans-tw-fonts adobe-source-han-sans-kr-fonts adobe-source-han-sans-jp-fonts
pacman -S --noconfirm --needed adobe-source-han-serif-cn-fonts adobe-source-han-serif-tw-fonts adobe-source-han-serif-kr-fonts adobe-source-han-serif-jp-fonts

# Post-update will clean things up.

==> fastec_3.2.6_49a.tar.xz: fi_update/pre/fi_update.sh <==
#!/bin/bash
set -x

SCRATCH_DIR="/home/fascam/.config/Fastec/scratch"

# Routine to compare version numbers in the form "x.y.z"
vercomp () {
    if [[ $1 == $2 ]]
    then
        return 0
    fi
    local IFS=.
    local i ver1=($1) ver2=($2)

    # fill empty fields in ver1 with zeros
    for ((i=${#ver1[@]}; i<${#ver2[@]}; i++))
    do
        ver1[i]=0
    done

    for ((i=0; i<${#ver1[@]}; i++))
    do
        if [[ -z ${ver2[i]} ]]
        then
            # fill empty fields in ver2 with zeros
            ver2[i]=0
        fi
        if ((10#${ver1[i]} > 10#${ver2[i]}))
        then
            return 1
        fi
        if ((10#${ver1[i]} < 10#${ver2[i]}))
        then
            return 2
        fi
    done
    return 0
}

# There is a conflict with the yay package and the latest version of pacman.
# We need to clear out the old yay, update pacman, then re-install yay.
update_pacman() {
    /usr/bin/logger "Update pacman/yay"
    pacman -R yay-bin --noconfirm 
    pacman -Sy pacman --noconfirm --needed 

    # Make sure we have a clean folder to work in.
    [ -d /tmp/yay ] && rm -rf /tmp/yay
    mkdir /tmp/yay
    chmod a+w /tmp/yay

    cd /tmp

    # Download the yay-bin package
    wget https://aur.archlinux.org/cgit/aur.git/plain/PKGBUILD?h=yay-bin
    mv PKGBUILD\?h\=yay-bin /tmp/yay/PKGBUILD
    cd /tmp/yay

    # Build and install yay.
    sudo -u fascam makepkg -i /tmp/yay --noconfirm

    # Cleanup after ourselves.
    [ -d /tmp/yay ] && rm -rf /tmp/yay
}

# Make sure the keyring is up to date.
/usr/bin/logger "Update ArchLinux key-ring"
pacman -Sy --noconfirm archlinux-keyring

# We are only interested in the "x.y.z" format.
PVER=`pacman -Qi pacman | grep Version | cut -d':' -f2 | cut -d'-' -f1`

# Is the pacman installed on this system at a safe version?
# A result of '2' means that the pacman installed on this system
# is less than 6.0.0, which is the "safe" version.
vercomp $PVER "6.0.0"
CRESULT=$?
if [ $CRESULT -eq 2 ]; then
    update_pacman
fi

# We may need Asian fonts.
/usr/bin/logger "Make sure we have our fonts"
pacman -S --noconfirm --needed adobe-source-han-sans-cn-fonts adobe-source-han-sans-tw-fonts adobe-source-han-sans-kr-fonts adobe-source-han-sans-jp-fonts
pacman -S --noconfirm --needed adobe-source-han-serif-cn-fonts adobe-source-han-serif-tw-fonts adobe-source-han-serif-kr-fonts adobe-source-han-serif-jp-fonts

# Post-update will clean things up.
